/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colordialog', 'sq', {
	clear: 'Pastro',
	highlight: 'Thekso',
	options: 'Përzgjedhjet e Ngjyrave',
	selected: 'Ngjyra e Përzgjedhur',
	title: 'Përzgjidh ngjyrë'
} );
